@@ -1,7 +1,7 @@
 # pylint: disable=C0114,C0115,R0913
 from __future__ import annotations
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 import json
 from json import JSONDecodeError
@@ -42,7 +42,7 @@ class MysqlConnector:
     async def __aexit__(self, exc_type, exc_val, exc_tb):
         await self.disconnect()
 
-    def __await__(self):
+    def __await__(self):  # pragma: no cover
         return self.__aenter__().__await__()
 
     async def disconnect(self) -> None:
